@@ -231,7 +231,7 @@ lnl.hlogit <- function(param, X, y, weights = NULL,
 lnl.rlogit <- function(param, X, y, weights = NULL,
                        gradient = TRUE, hessian = FALSE, opposite = TRUE,
                        direction = rep(0, length(param)), initial.value = NULL, stptol = 1e-10,
-                       R, seed, id, rpar, correlation){
+                       R, seed, id, rpar, correlation, halton){
   panel <- !is.null(id)
   otime <- proc.time()
   K <- ncol(X[[1]])
@@ -248,7 +248,6 @@ lnl.rlogit <- function(param, X, y, weights = NULL,
   Xa <- lapply(X, function(x) x[, Vara, drop = F])
   Xc <- lapply(X, function(x) x[, Varc, drop = F])
   K <- Kc + Ka
-  halton <- NA
   set.seed(seed)
   random.nb <- make.random.nb(R * ifelse(!is.null(id), n, N), Ka, halton)
   step <- 2
